// BWLineCap(View).m -- show a big fat line with different line caps

// Copyright (C) 2002 Borkware
// We use the BSD License.  Check out http://borkware.com/license

#import "BWLineCap.h"

#define DEFAULT_LINE_WIDTH 	20
#define DEFAULT_LINE_CAP_STYLE	NSButtLineCapStyle

@implementation BWLineCap

// set defaults.  build the bezier path with a diagonal line

- (id) initWithFrame: (NSRect) frame 
{
    if (self = [super initWithFrame: frame]) {
	NSPoint middlePoint = NSMakePoint (frame.size.width / 2,
					   frame.size.height / 2);
	path = [NSBezierPath bezierPath];
	[path setLineWidth: DEFAULT_LINE_WIDTH];
	[path setLineCapStyle: DEFAULT_LINE_CAP_STYLE];
	[path moveToPoint: NSMakePoint (0, 0)];
	[path lineToPoint: middlePoint];
	[path retain];
    }

    return (self);

} // initWithFrame



- (void) drawRect:(NSRect)rect 
{
    NSPoint lineEnd;

    rect = [self bounds];

    // erase to a nice white color
    [[NSColor whiteColor] set];
    [NSBezierPath fillRect: rect];

    // draw the line
    [[NSColor blackColor] set];
    [NSBezierPath strokeRect: rect];

    [path stroke];

    [[NSColor whiteColor] set];

    // draw the indicator of the actual path
    lineEnd = NSMakePoint (rect.size.width / 2, rect.size.height / 2);
    [NSBezierPath strokeLineFromPoint: NSZeroPoint toPoint: lineEnd];

} // drawRect



- (void) setLineWidth: (float) lineWidth
{
    [path setLineWidth: lineWidth];
} // setLineWidth



- (void) setLineCapStyle: (NSLineCapStyle) style
{
    [path setLineCapStyle: style];
} // setLineCapStyle



- (void) dealloc
{
    [path release];
    [super dealloc];
} // dealloc

@end // BWLineCap

