// BWLineJoin(View).m -- Show different line joins, and play with the
//                       miter limit

// Copyright (C) 2002 Borkware
// We use the BSD License.  Check out http://borkware.com/license

#import "BWLineJoin.h"

// the out-of-the-gate defaults

#define DEFAULT_LINE_WIDTH 	20
#define DEFAULT_LINE_CAP_STYLE	NSButtLineCapStyle
#define DEFAULT_MITER_LIMIT	10.0


@implementation BWLineJoin

// create a path of an angled line.  Also set the default drawing
// behavios

- (id)initWithFrame:(NSRect)frame 
{
    if (self = [super initWithFrame: frame]) {
	NSPoint middlePoint = NSMakePoint (frame.size.width / 2,
					   frame.size.height / 2);
	NSPoint bottomRightPoint = NSMakePoint (frame.size.width, 0);

	path = [NSBezierPath bezierPath];
	[path setLineWidth: DEFAULT_LINE_WIDTH];
	[path setLineCapStyle: DEFAULT_LINE_CAP_STYLE];
	[path setMiterLimit: DEFAULT_MITER_LIMIT];
	[path moveToPoint: NSMakePoint (0, 0)];
	[path lineToPoint: middlePoint];
	[path lineToPoint: bottomRightPoint];
	[path retain];
    }

    return (self);

} // initWithFrame



- (void)drawRect:(NSRect)rect 
{
    NSPoint middlePoint;
    NSPoint endPoint;

    rect = [self bounds];

    // make a nice white background to draw on
    [[NSColor whiteColor] set];
    [NSBezierPath fillRect: rect];

    // and go ahead and frame it
    [[NSColor blackColor] set];
    [NSBezierPath strokeRect: rect];

    // draw the path
    [path stroke];

    // and draw the abstract path
    [[NSColor whiteColor] set];

    middlePoint = NSMakePoint (rect.size.width / 2, rect.size.height / 2);
    endPoint = NSMakePoint (rect.size.width, 0);

    [NSBezierPath strokeLineFromPoint: NSZeroPoint toPoint: middlePoint];
    [NSBezierPath strokeLineFromPoint: middlePoint toPoint: endPoint];

} // drawRect



- (void) setLineWidth: (float) lineWidth
{
    [path setLineWidth: lineWidth];
} // setLineWidth



- (void) setMiterLimit: (float) miterLimit
{
    [path setMiterLimit: miterLimit];
} // setMiterLimit



- (void) setLineJoinStyle: (NSLineJoinStyle) style
{
    [path setLineJoinStyle: style];
} // setLineJoinStyle



- (void) dealloc
{
    [path release];
	[super dealloc];
	
} // dealloc


@end // BWLineJoin

